@@ -874,7 +874,7 @@ static struct cityresult *settler_map_iterate(struct ai_type *ait,
 /**************************************************************************
   Find nearest and best city placement or (TODO) a city to immigrate to.
 
-  Option look_for_boat forces us to find a (real) boat before cosidering
+  Option look_for_boat forces us to find a (real) boat before considering
   going overseas.  Option use_virt_boat allows to use virtual boat but only
   if punit is in a coastal city right now (should only be used by 
   virtual units).  I guess it won't hurt to remove this condition, PF 
@@ -1243,11 +1243,17 @@ static bool dai_do_build_city(struct ai_type *ait, struct player *pplayer,
               player_name(pplayer), TILE_XY(ptile));
     return FALSE;
   }
-  handle_unit_build_city(pplayer, punit->id,
-                         city_name_suggestion(pplayer, ptile));
+  if (!unit_build_city(pplayer, punit, city_name_suggestion(pplayer, ptile))) {
+    /* It's an error when unit_build_city() says that request was illegal to begin with. */
+    log_error("%s: Failed to build city at (%d, %d)",
+              player_name(pplayer), TILE_XY(ptile));
+    return FALSE;
+  }
+
   pcity = tile_city(ptile);
   if (!pcity) {
-    log_error("%s: Failed to build city at (%d, %d)",
+    /* Write just debug log when city building didn't success for acceptable reason. */
+    log_debug("%s: Failed to build city at (%d, %d)",
               player_name(pplayer), TILE_XY(ptile));
     return FALSE;
   }
