@@ -15,12 +15,22 @@
 #include <fc_config.h>
 #endif
 
+/* Must be before <windows.h> */
+#ifdef HAVE_WINSOCK
+#ifdef HAVE_WINSOCK2
+#include <winsock2.h>
+#else  /* HAVE_WINSOCK2 */
+#include <winsock.h>
+#endif /* HAVE_WINSOCK2 */
+#endif /* HAVE_WINSOCK */
+
 #ifdef WIN32_NATIVE
 #include <windows.h>	/* LoadLibrary() */
 #endif
 
 #include <math.h>
 #include <signal.h>
+#include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
@@ -1089,7 +1099,7 @@ double real_timer_callback(void)
 bool can_client_control(void)
 {
   return (NULL != client.conn.playing
-	  && !client_is_observer());
+          && !client_is_observer());
 }
 
 /**************************************************************************
