@@ -437,6 +437,7 @@ void races_dialog::nation_selected(const QItemSelection &selected,
   helptext_nation(buf, sizeof(buf), nation_by_number(selected_nation), NULL);
   description->setText(buf);
   leader_name->clear();
+  leader_name->addItem(client.conn.playing->name, true);
   nation_leader_list_iterate(nation_leaders(nation_by_number
                                             (selected_nation)), pleader) {
     str = QString::fromUtf8(nation_leader_name(pleader));
@@ -530,7 +531,8 @@ void races_dialog::ok_pressed()
                                  selected_nation, selected_sex,
                                  leader_name->currentText().toUtf8().data(),
                                  selected_style);
-  delete this;
+  close();
+  deleteLater();
 }
 
 /***************************************************************************
@@ -2048,7 +2050,18 @@ void show_tech_gained_dialog(Tech_type_id tech)
 *****************************************************************/
 void show_tileset_error(const char *msg)
 {
-  /* PORTME */
+  QMessageBox ask(gui()->central_wdg);
+  char buf[1024];
+
+  fc_snprintf(buf, sizeof(buf),
+              _("Tileset problem, it's probably incompatible with the"
+                " ruleset:\n%s\nProgram will now exit."), msg);
+  ask.setText(buf);
+  ask.setStandardButtons(QMessageBox::Ok);
+  ask.setWindowTitle(_("Tileset error"));
+  ask.exec();
+  gui()->quit();
+
 }
 
 /****************************************************************
