@@ -72,7 +72,6 @@ fc_client::fc_client() : QMainWindow()
   button_box = NULL;
   server_notifier = NULL;
   chat_line = NULL;
-  connect_tab_widget = NULL;
   lan_widget = NULL;
   wan_widget = NULL;
   info_widget = NULL;
@@ -155,8 +154,6 @@ void fc_client::init()
   // PAGE_NETWORK
   pages[PAGE_NETWORK] = new QWidget(central_wdg);
   create_network_page();
-  meta_scan_timer = new QTimer;
-  lan_scan_timer = new QTimer;
   pages[PAGE_NETWORK]->setVisible(false);
 
   // PAGE_GAME
@@ -200,13 +197,12 @@ fc_client::~fc_client()
 ****************************************************************************/
 void fc_client::main(QApplication *qapp)
 {
-
   qRegisterMetaType<QTextCursor>("QTextCursor");
   qRegisterMetaType<QTextBlock>("QTextBlock");
   fc_allocate_ow_mutex();
   real_output_window_append(_("This is Qt-client for Freeciv."), NULL, -1);
   fc_release_ow_mutex();
-  chat_welcome_message();
+  chat_welcome_message(true);
 
   set_client_state(C_S_DISCONNECTED);
 
@@ -498,6 +494,8 @@ void fc_client::slot_pregame_start()
     dsend_packet_player_ready(&client.conn,
                               player_number(client_player()),
                               !client_player()->is_ready);
+  } else {
+    dsend_packet_player_ready(&client.conn, 0, TRUE);
   }
 }
 
@@ -863,7 +861,7 @@ void pregame_options::init()
 
   l1 = new QLabel(_("Number of Players\n(including AI):"));
   l2 = new QLabel(_("AI Skill Level:"));
-  l3 = new QLabel(_("Ruleset Version:"));
+  l3 = new QLabel(_("Ruleset:"));
   layout = new QGridLayout(this);
   max_players = new QSpinBox(this);
   ailevel = new QComboBox(this);
