@@ -164,8 +164,6 @@ class fc_client : public QMainWindow
 
   QLineEdit *chat_line;
 
-  QTabWidget *connect_tab_widget;
-
   QTableWidget* lan_widget;
   QTableWidget* wan_widget;
   QTableWidget* info_widget;
@@ -247,7 +245,6 @@ private slots:
 
   void server_input(int sock);
   void chat();
-  void quit();
   void closing();
   void slot_lan_scan();
   void slot_meta_scan();
@@ -266,12 +263,12 @@ private slots:
   void browse_saves();
   void browse_scenarios();
   void clear_status_bar();
-  void network_tab_changed(int index);
 
 public slots:
   void switch_page(int i);
   void popup_client_options();
   void update_info_label();
+  void quit();
 
 protected slots:
 
