@@ -196,15 +196,16 @@ void gov_menu::create() {
   gov_mapper->deleteLater();
   gov_mapper = new QSignalMapper();
 
+  gov_count = government_count();
+  actions.reserve(gov_count + 1);
   action = addAction(_("Revolution..."));
   connect(action, &QAction::triggered, this, &gov_menu::revolution);
+  actions.append(action);
 
   addSeparator();
 
   // Add an action for each government. There is no icon yet.
-  gov_count = government_count();
   revol_gov = game.government_during_revolution;
-  actions.reserve(gov_count);
   for (i = 0; i < gov_count; ++i) {
     gov = government_by_number(i);
     if (gov != revol_gov) { // Skip revolution goverment
@@ -235,11 +236,13 @@ void gov_menu::update()
     if (gov != revol_gov) { // Skip revolution goverment
       sprite = get_government_sprite(tileset, gov);
       if (sprite != NULL) {
-        actions[j]->setIcon(QIcon(*(sprite->pm)));
+        actions[j + 1]->setIcon(QIcon(*(sprite->pm)));
       }
-      actions[j]->setEnabled(
-          can_change_to_government(client.conn.playing, gov));
+      actions[j + 1]->setEnabled(
+        can_change_to_government(client.conn.playing, gov));
       ++j;
+    } else {
+      actions[0]->setEnabled(!client_is_observer());
     }
   }
 }
@@ -715,7 +718,7 @@ void mr_menu::setup_menus()
   menu_list.insertMulti(BUILD, act);
   connect(act, SIGNAL(triggered()), this, SLOT(slot_build_city()));
   act = menu->addAction(_("Go And Build City"));
-  menu_list.insertMulti(AUTOSETTLER, act);
+  menu_list.insertMulti(GO_AND_BUILD_CITY, act);
   act->setShortcut(QKeySequence(tr("shift+b")));
   connect(act, SIGNAL(triggered()), this, SLOT(slot_go_build_city()));
   act = menu->addAction(_("Auto Settler"));
@@ -773,6 +776,7 @@ void mr_menu::setup_menus()
   /* Civilization menu */
   menu = this->addMenu(_("Civilization"));
   act = menu->addAction(_("Tax Rates..."));
+  menu_list.insertMulti(NOT_4_OBS, act);
   connect(act, SIGNAL(triggered()), this, SLOT(slot_popup_tax_rates()));
   menu->addSeparator();
 
@@ -787,7 +791,8 @@ void mr_menu::setup_menus()
   act->setShortcut(QKeySequence(tr("F2")));
   connect(act, SIGNAL(triggered()), this, SLOT(slot_show_units_report()));
 
-  act = menu->addAction(_("Players"));
+  /* TRANS: Also menu item, but 'headers' should be good enough. */
+  act = menu->addAction(Q_("?header:Players"));
   act->setShortcut(QKeySequence(tr("F3")));
   connect(act, SIGNAL(triggered()), this, SLOT(slot_show_nations()));
 
@@ -978,6 +983,10 @@ void mr_menu::menus_sensitive()
           i.value()->setEnabled(true);
         }
         break;
+      case NOT_4_OBS:
+        if (client_is_observer() == false) {
+          i.value()->setEnabled(true);
+        }
       default:
         break;
       }
@@ -1201,8 +1210,17 @@ void mr_menu::menus_sensitive()
         if (can_units_do(punits, can_unit_do_autosettlers)) {
           i.value()->setEnabled(true);
         }
+        if (units_have_type_flag(punits, UTYF_CITIES, true)) {
+          i.value()->setText(_("Auto Settler"));
+        } else {
+          i.value()->setText(_("Auto Worker"));
+        }
+        break;
+      case GO_AND_BUILD_CITY:
+        if (units_have_type_flag(punits, UTYF_CITIES, TRUE)) {
+          i.value()->setEnabled(true);
+        }
         break;
-
       case CONNECT_ROAD:
         proad = road_by_compat_special(ROCO_ROAD);
         if (proad != NULL) {
