@@ -250,6 +250,7 @@ void fc_client::create_network_page(void)
 {
   QHeaderView *header;
   QLabel *connect_msg;
+  QLabel *lan_label;
   QPushButton *network_button;
 
   pages_layout[PAGE_NETWORK] = new QGridLayout;
@@ -269,7 +270,6 @@ void fc_client::create_network_page(void)
 
   connect_password_edit->setDisabled(true);
   connect_confirm_password_edit->setDisabled(true);
-  connect_tab_widget = new QTabWidget;
   connect_lan = new QWidget;
   connect_metaserver = new QWidget;
   lan_widget = new QTableWidget;
@@ -278,7 +278,7 @@ void fc_client::create_network_page(void)
 
   QStringList servers_list;
   servers_list << _("Server Name") << _("Port") << _("Version")
-               << _("Status") << _("Players") << _("Comment");
+               << _("Status") << Q_("?count:Players") << _("Comment");
   QStringList server_info;
   server_info << _("Name") << _("Type") << _("Host") << _("Nation");
 
@@ -300,11 +300,13 @@ void fc_client::create_network_page(void)
   lan_widget->setProperty("showGrid", "false");
   lan_widget->setProperty("selectionBehavior", "SelectRows");
   lan_widget->setEditTriggers(QAbstractItemView::NoEditTriggers);
+  lan_widget->setSelectionMode(QAbstractItemView::SingleSelection);
 
   wan_widget->setHorizontalHeaderLabels(servers_list);
   wan_widget->setProperty("showGrid", "false");
   wan_widget->setProperty("selectionBehavior", "SelectRows");
   wan_widget->setEditTriggers(QAbstractItemView::NoEditTriggers);
+  wan_widget->setSelectionMode(QAbstractItemView::SingleSelection);
 
   connect(wan_widget->selectionModel(),
           SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)), this,
@@ -369,13 +371,14 @@ void fc_client::create_network_page(void)
 
   connect_lan->setLayout(page_network_lan_layout);
   connect_metaserver->setLayout(page_network_wan_layout);
-  page_network_lan_layout->addWidget(lan_widget, 1);
+  page_network_lan_layout->addWidget(lan_widget, 0);
   page_network_wan_layout->addWidget(wan_widget, 1);
-  page_network_layout->addWidget(connect_tab_widget, 1);
-  connect_tab_widget->addTab(connect_lan, _("LAN"));
-  connect_tab_widget->addTab(connect_metaserver, _("NETWORK"));
-  connect(connect_tab_widget, SIGNAL(currentChanged(int)),
-         this, SLOT(network_tab_changed(int)));
+  lan_label = new QLabel(_("Internet servers:"));
+  page_network_layout->addWidget(lan_label, 1);
+  page_network_layout->addWidget(wan_widget, 10);
+  lan_label = new QLabel(_("Local servers:"));
+  page_network_layout->addWidget(lan_label, 1);
+  page_network_layout->addWidget(lan_widget, 1);
   page_network_grid_layout->setColumnStretch(3, 4);
   pages_layout[PAGE_NETWORK]->addLayout(page_network_layout, 1, 1);
   pages_layout[PAGE_NETWORK]->addLayout(page_network_grid_layout, 2, 1);
@@ -450,7 +453,7 @@ void fc_client::create_load_page()
           SLOT(slot_selection_changed(const QItemSelection &, const QItemSelection &)));
 
   but = new QPushButton;
-  but->setText(_("_Browse..."));
+  but->setText(_("Browse..."));
   but->setIcon(QApplication::style()->standardIcon(QStyle::SP_DirIcon));
   connect(but, SIGNAL(clicked()), this, SLOT(browse_saves()));
   pages_layout[PAGE_LOAD]->addWidget (but, 1, 0);
@@ -459,7 +462,7 @@ void fc_client::create_load_page()
   but->setText(_("Cancel"));
   but->setIcon(QApplication::style()->standardIcon(
                                       QStyle::SP_DialogCancelButton));
-  connect(but, SIGNAL(clicked()), switch_page_mapper, SLOT(map()));
+  connect(but, SIGNAL(clicked()), this, SLOT(slot_disconnect()));
   switch_page_mapper->setMapping(but, PAGE_MAIN);
   pages_layout[PAGE_LOAD]->addWidget(but, 1, 2);
 
@@ -508,7 +511,7 @@ void fc_client::create_scenario_page()
           SLOT(slot_selection_changed(const QItemSelection &, const QItemSelection &)));
 
   but = new QPushButton;
-  but->setText(_("_Browse..."));
+  but->setText(_("Browse..."));
   but->setIcon(QApplication::style()->standardIcon(QStyle::SP_DirIcon));
   connect(but, SIGNAL(clicked()), this, SLOT(browse_scenarios()));
   pages_layout[PAGE_SCENARIO]->addWidget (but, 4, 0);
@@ -517,7 +520,7 @@ void fc_client::create_scenario_page()
   but->setText(_("Cancel"));
   but->setIcon(QApplication::style()->standardIcon(
                                         QStyle::SP_DialogCancelButton));
-  connect(but, SIGNAL(clicked()), switch_page_mapper, SLOT(map()));
+  connect(but, SIGNAL(clicked()), this, SLOT(slot_disconnect()));
   switch_page_mapper->setMapping(but, PAGE_MAIN);
   pages_layout[PAGE_SCENARIO]->addWidget(but, 4, 3);
 
@@ -829,24 +832,6 @@ void server_scan_error(struct server_scan *scan, const char *message)
   }
 }
 
-/***************************************************************************
-  Tab in network page has been changed.
-  Force current selection change to emit signal.
-***************************************************************************/
-void fc_client::network_tab_changed(int index)
-{
-  QWidget *w;
-  QHBoxLayout *l;
-  QTableWidget *tw;
-  int i;
-
-  w = connect_tab_widget->currentWidget();
-  l = qobject_cast<QHBoxLayout *>(w->layout());
-  tw = qobject_cast<QTableWidget *>(l->itemAt(0)->widget());
-  i = tw->currentRow();
-  tw->clearSelection();
-  tw->selectRow(i);
-}
 
 /**************************************************************************
   Free the server scans.
@@ -998,9 +983,7 @@ void fc_client::slot_selection_changed(const QItemSelection &selected,
   QStringList sl;
   QModelIndex index;
   QTableWidgetItem *item;
-  QWidget *w;
-  QHBoxLayout *l;
-  QTableWidget *tw;
+  QItemSelectionModel *tw;
   QVariant qvar;
   int k, col, n;
   client_pages i = current_page();
@@ -1018,13 +1001,14 @@ void fc_client::slot_selection_changed(const QItemSelection &selected,
     index = indexes.at(1);
     connect_port_edit->setText(index.data().toString());
 
-    w = connect_tab_widget->currentWidget();
-    l = qobject_cast<QHBoxLayout *>(w->layout());
-    tw = qobject_cast<QTableWidget *>(l->itemAt(0)->widget());
+    tw = qobject_cast<QItemSelectionModel *>(sender());
 
-    if (tw == lan_widget) {
-      return;
+    if (tw == lan_widget->selectionModel()) {
+      wan_widget->clearSelection();
+    } else {
+      lan_widget->clearSelection();
     }
+
     srvrs = server_scan_get_list(meta_scan);
     if (!holding_srv_list_mutex) {
       fc_allocate_mutex(&srvrs->mutex);
@@ -1165,6 +1149,7 @@ void fc_client::handle_authentication_req(enum authentication_type type,
                                           const char *message)
 {
   set_status_bar(QString::fromUtf8(message));
+  destroy_server_scans();
 
   switch (type) {
   case AUTH_NEWUSER_FIRST:
@@ -1275,7 +1260,7 @@ void fc_client::update_start_page()
   qvar2 = 0;
 
   player_item = new QTreeWidgetItem();
-  player_item->setText(0, _("Players"));
+  player_item->setText(0, Q_("?header:Players"));
   player_item->setData(0, Qt::UserRole, qvar2);
 
   i = 0;
@@ -1491,7 +1476,19 @@ void fc_client::update_buttons()
     }
   } else {
     text = _("Start");
-    sensitive = false;
+    if (can_client_access_hack()) {
+      sensitive = true;
+      players_iterate(plr) {
+        if (!plr->ai_controlled) {
+          /* There's human controlled player(s) in game, so it's their
+           * job to start the game. */
+          sensitive = false;
+          break;
+        }
+      } players_iterate_end;
+    } else {
+      sensitive = false;
+    }
   }
   li = pages_layout[PAGE_START]->itemAtPosition(5, 7);
   pb = qobject_cast<QPushButton *>(li->widget());
