@@ -24,7 +24,7 @@
 #endif
 
 /* SDL */
-#include "SDL.h"
+#include "SDL/SDL.h"
 
 /* utility */
 #include "astring.h"
@@ -497,10 +497,15 @@ void redraw_unit_info_label(struct unit_list *punitlist)
   SDL_Surface *pBuf_Surf, *pTmpSurf;
   SDL_String16 *pStr;
   struct canvas *destcanvas;
-  struct unit *pUnit = unit_list_get(punitlist, 0);
+  struct unit *pUnit;
+
+  if (punitlist != NULL && unit_list_size(punitlist) > 0) {
+    pUnit = unit_list_get(punitlist, 0);
+  } else {
+    pUnit = NULL;
+  }
 
   if (SDL_Client_Flags & CF_UNITINFO_SHOWN) {
-    
     pInfo_Window = get_unit_info_window_widget();
 
     /* blit theme surface */
@@ -900,7 +905,7 @@ void redraw_unit_info_label(struct unit_list *punitlist)
 	hide_scrollbar(pInfo_Window->private_data.adv_dlg->pScroll);
       }
 
-      if (!client_is_observer()
+      if (!client_is_observer() && !client.conn.playing->phase_done
           && (!client.conn.playing->ai_controlled || ai_manual_turn_done)) {
         char buf[256];
         fc_snprintf(buf, sizeof(buf), "%s\n%s\n%s",
@@ -968,7 +973,7 @@ void real_focus_units_changed(void)
   the square under the current unit, for specified unit.  Note that in
   practice punit is always the focus unit.
 
-  Clears label if punit is NULL.
+  Clears label if punitlist is NULL or empty.
 
   Typically also updates the cursor for the map_canvas (this is related
   because the info label may includes  "select destination" prompt etc).
