@@ -13,18 +13,22 @@
 #ifndef FC__SPRITE_G_H
 #define FC__SPRITE_G_H
 
+#include "gui_proto_constructor.h"
+
 struct sprite;			/* opaque type, real type is gui-dep */
 struct color;
 
-const char **gfx_fileextensions(void);
+GUI_FUNC_PROTO(const char **, gfx_fileextensions, void)
 
-struct sprite *load_gfxfile(const char *filename);
-struct sprite *crop_sprite(struct sprite *source,
-                           int x, int y, int width, int height,
-                           struct sprite *mask,
-                           int mask_offset_x, int mask_offset_y);
-struct sprite *create_sprite(int width, int height, struct color *pcolor);
-void get_sprite_dimensions(struct sprite *sprite, int *width, int *height);
-void free_sprite(struct sprite *s);
+GUI_FUNC_PROTO(struct sprite *, load_gfxfile, const char *filename)
+GUI_FUNC_PROTO(struct sprite *, crop_sprite, struct sprite *source,
+               int x, int y, int width, int height,
+               struct sprite *mask,
+               int mask_offset_x, int mask_offset_y)
+GUI_FUNC_PROTO(struct sprite *, create_sprite, int width, int height,
+               struct color *pcolor)
+GUI_FUNC_PROTO(void, get_sprite_dimensions, struct sprite *sprite,
+               int *width, int *height)
+GUI_FUNC_PROTO(void, free_sprite, struct sprite *s)
 
 #endif  /* FC__SPRITE_G_H */
