@@ -1,4 +1,4 @@
-/********************************************************************** 
+/***********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -1040,7 +1040,8 @@ bool player_in_city_map(const struct player *pplayer,
   city_tile_iterate(CITY_MAP_MAX_RADIUS_SQ, ptile, ptile1) {
     struct city *pcity = tile_city(ptile1);
 
-    if (pcity && city_owner(pcity) == pplayer
+    if (pcity
+        && (pplayer == NULL || city_owner(pcity) == pplayer)
         && city_map_radius_sq_get(pcity) >= sq_map_distance(ptile,
                                                             ptile1)) {
       return TRUE;
@@ -1303,10 +1304,15 @@ bool players_non_invade(const struct player *pplayer1,
   if (pplayer1 == pplayer2 || !pplayer1 || !pplayer2) {
     return FALSE;
   }
+
   if (is_barbarian(pplayer1) || is_barbarian(pplayer2)) {
     /* Likely an unnecessary test. */
     return FALSE;
   }
+
+  /* Movement during armistice is allowed so that player can withdraw
+     units deeper inside opponent territory. */
+
   return player_diplstate_get(pplayer1, pplayer2)->type == DS_PEACE;
 }
 
@@ -1335,14 +1341,6 @@ bool players_on_same_team(const struct player *pplayer1,
   return pplayer1->team == pplayer2->team;
 }
 
-/**************************************************************************
-  Return TRUE iff player is any kind of barbarian
-**************************************************************************/
-bool is_barbarian(const struct player *pplayer)
-{
-  return pplayer->ai_common.barbarian_type != NOT_A_BARBARIAN;
-}
-
 /**************************************************************************
   Return TRUE iff the player me gives shared vision to player them.
 **************************************************************************/
