@@ -57,14 +57,15 @@ void handle_unit_autosettlers(struct player *pplayer, int unit_id);
 void handle_unit_load(struct player *pplayer, int cargo_id, int transporter_id);
 void handle_unit_unload(struct player *pplayer, int cargo_id, int transporter_id);
 void handle_unit_upgrade(struct player *pplayer, int unit_id);
-void handle_unit_convert(struct player *pplayer, int unit_id);
 void handle_unit_nuke(struct player *pplayer, int unit_id);
 void handle_unit_paradrop_to(struct player *pplayer, int unit_id, int tile);
 void handle_unit_airlift(struct player *pplayer, int unit_id, int city_id);
 void handle_unit_diplomat_query(struct connection *pc, int diplomat_id, int target_id, int value, enum diplomat_actions action_type);
 void handle_unit_type_upgrade(struct player *pplayer, Unit_type_id type);
 void handle_unit_diplomat_action(struct player *pplayer, int diplomat_id, int target_id, int value, enum diplomat_actions action_type);
-void handle_unit_change_activity(struct player *pplayer, int unit_id, enum unit_activity activity, enum tile_special_type activity_target, Base_type_id activity_base);
+void handle_unit_change_activity(struct player *pplayer, int unit_id, enum unit_activity activity, enum tile_special_type activity_target);
+void handle_unit_change_activity_base(struct player *pplayer, int unit_id, enum unit_activity activity, Base_type_id activity_base);
+void handle_unit_change_activity_road(struct player *pplayer, int unit_id, enum unit_activity activity, Road_type_id activity_road);
 void handle_diplomacy_init_meeting_req(struct player *pplayer, int counterpart);
 void handle_diplomacy_cancel_meeting_req(struct player *pplayer, int counterpart);
 void handle_diplomacy_create_clause_req(struct player *pplayer, int counterpart, int giver, enum clause_type type, int value);
@@ -78,8 +79,6 @@ void handle_spaceship_launch(struct player *pplayer);
 void handle_spaceship_place(struct player *pplayer, enum spaceship_place_type type, int num);
 struct packet_single_want_hack_req;
 void handle_single_want_hack_req(struct connection *pc, const struct packet_single_want_hack_req *packet);
-struct packet_scenario_info;
-void handle_scenario_info(struct connection *pc, const struct packet_scenario_info *packet);
 void handle_save_scenario(struct connection *pc, const char *name);
 void handle_vote_submit(struct connection *pc, int vote_no, int value);
 void handle_edit_mode(struct connection *pc, bool state);
@@ -90,6 +89,7 @@ void handle_edit_tile_terrain(struct connection *pc, int tile, Terrain_type_id t
 void handle_edit_tile_resource(struct connection *pc, int tile, Resource_type_id resource, int size);
 void handle_edit_tile_special(struct connection *pc, int tile, enum tile_special_type special, bool remove, int size);
 void handle_edit_tile_base(struct connection *pc, int tile, Base_type_id base_type_id, bool remove, int size);
+void handle_edit_tile_road(struct connection *pc, int tile, Road_type_id road_type_id, bool remove, int size);
 struct packet_edit_startpos;
 void handle_edit_startpos(struct connection *pc, const struct packet_edit_startpos *packet);
 struct packet_edit_startpos_full;
