@@ -56,7 +56,14 @@
 #include <unistd.h>
 #endif
 #ifdef HAVE_WINSOCK
+#ifdef HAVE_WINSOCK2
+#include <winsock2.h>
+#else  /* HAVE_WINSOCK2 */
 #include <winsock.h>
+#endif /* HAVE_WINSOCK2 */
+#endif /* HAVE_WINSOCK */
+#ifdef HAVE_WS2TCPIP_H
+#include <ws2tcpip.h>
 #endif
 
 /* utility */
@@ -300,7 +307,7 @@ static void really_close_connections(void)
       lost_connection_to_client(pconn);
       close_connection(pconn);
     }
-  } while (0 < num); /* May some errors occured, let's check. */
+  } while (0 < num); /* May some errors occurred, let's check. */
 }
 
 /****************************************************************************
