@@ -350,10 +350,14 @@ void handle_unit_diplomat_action(struct player *pplayer,
 }
 
 /**************************************************************************
-  Transfer a unit from one homecity to another. This new homecity must
-  be valid for this unit.
+  Transfer a unit from one city (and possibly player) to another.
+  If 'rehome' is not set, only change the player which owns the unit
+  (the new owner is new_pcity's owner). Otherwise the new unit will be
+  given a homecity, even if it was homeless before.
+  This new homecity must be valid for this unit.
 **************************************************************************/
-void unit_change_homecity_handling(struct unit *punit, struct city *new_pcity)
+void unit_change_homecity_handling(struct unit *punit, struct city *new_pcity,
+                                   bool rehome)
 {
   struct city *old_pcity = game_city_by_number(punit->homecity);
   struct player *old_owner = unit_owner(punit);
@@ -364,6 +368,10 @@ void unit_change_homecity_handling(struct unit *punit, struct city *new_pcity)
    * be used that way. */
   fc_assert_ret(new_pcity != old_pcity);
 
+  /* If 'rehome' is not set, this function should only be used to change
+   * which player owns the unit */
+  fc_assert_ret(rehome || new_owner != old_owner);
+
   if (old_owner != new_owner) {
     struct city *pcity = tile_city(punit->tile);
 
@@ -375,11 +383,11 @@ void unit_change_homecity_handling(struct unit *punit, struct city *new_pcity)
 
     if (pcity != NULL
         && !can_player_see_units_in_city(old_owner, pcity)) {
-      /* Special case when city is being transfered. At this point city
+      /* Special case when city is being transferred. At this point city
        * itself has changed owner, so it's enemy city now that old owner
-       * cannot see inside. All the normal methods of removing transfered
+       * cannot see inside. All the normal methods of removing transferred
        * unit from previous owner's client think that there's no need to
-       * remove unit as client should't have it in first place. */
+       * remove unit as client shouldn't have it in first place. */
       unit_goes_out_of_sight(old_owner, punit);
     }
 
@@ -397,24 +405,28 @@ void unit_change_homecity_handling(struct unit *punit, struct city *new_pcity)
     unit_refresh_vision(punit);
   }
 
-  /* Remove from old city first and add to new city only after that.
-   * This is more robust in case old_city == new_city (currently
-   * prohibited by fc_assert in the beginning of the function).
-   */
-  if (old_pcity) {
-    /* Even if unit is dead, we have to unlink unit pointer (punit). */
-    unit_list_remove(old_pcity->units_supported, punit);
+  if (rehome) {
+    fc_assert(!unit_has_type_flag(punit, UTYF_NOHOME));
+
+    /* Remove from old city first and add to new city only after that.
+     * This is more robust in case old_city == new_city (currently
+     * prohibited by fc_assert in the beginning of the function).
+     */
+    if (old_pcity) {
+      /* Even if unit is dead, we have to unlink unit pointer (punit). */
+      unit_list_remove(old_pcity->units_supported, punit);
+      /* update unit upkeep */
+      city_units_upkeep(old_pcity);
+    }
+
+    unit_list_prepend(new_pcity->units_supported, punit);
+
     /* update unit upkeep */
-    city_units_upkeep(old_pcity);
+    city_units_upkeep(new_pcity);
+
+    punit->homecity = new_pcity->id;
   }
 
-  unit_list_prepend(new_pcity->units_supported, punit);
-
-  /* update unit upkeep */
-  city_units_upkeep(new_pcity);
-
-  punit->homecity = new_pcity->id;
-
   if (!can_unit_continue_current_activity(punit)) {
     /* This is mainly for cases where unit owner changes to one not knowing
      * Railroad tech when unit is already building railroad. */
@@ -453,7 +465,7 @@ void handle_unit_change_homecity(struct player *pplayer, int unit_id,
   }
 
   if (pcity && can_unit_change_homecity_to(punit, pcity)) {
-    unit_change_homecity_handling(punit, pcity);
+    unit_change_homecity_handling(punit, pcity, TRUE);
   }
 }
 
@@ -680,24 +692,24 @@ static void city_build(struct player *pplayer, struct unit *punit,
 }
 
 /**************************************************************************
-  Handle city building request. Can result in adding to existing city
-  also.
+  Try to build city.
+  Return value tells if request was sane. It can be TRUE even if city
+  building failed, as long as the reason was not bad request.
 **************************************************************************/
-void handle_unit_build_city(struct player *pplayer, int unit_id,
-                            const char *name)
+bool unit_build_city(struct player *pplayer, struct unit *punit,
+                     const char *name)
 {
   enum unit_add_build_city_result res;
-  struct unit *punit = player_unit_by_number(pplayer, unit_id);
 
   if (NULL == punit) {
     /* Probably died or bribed. */
-    log_verbose("handle_unit_build_city() invalid unit %d", unit_id);
-    return;
+    log_verbose("unit_build_city() invalid unit.");
+    return FALSE;
   }
 
   if (!unit_can_do_action_now(punit)) {
     /* Building a city not possible due to unitwaittime setting. */
-    return;
+    return FALSE;
   }
 
   res = unit_add_or_build_city_test(punit);
@@ -708,7 +720,22 @@ void handle_unit_build_city(struct player *pplayer, int unit_id,
     city_add_unit(pplayer, punit);
   } else {
     city_add_or_build_error(pplayer, punit, res);
+    if (res != UAB_NO_MIN_DIST) {
+      return FALSE;
+    }
   }
+
+  return TRUE;
+}
+
+/**************************************************************************
+  Handle city building request. Can result in adding to existing city
+  also.
+**************************************************************************/
+void handle_unit_build_city(struct player *pplayer, int unit_id,
+                            const char *name)
+{
+  unit_build_city(pplayer, player_unit_by_number(pplayer, unit_id), name);
 }
 
 /**************************************************************************
