@@ -1,4 +1,4 @@
-/********************************************************************** 
+/**********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -11,17 +11,17 @@
    GNU General Public License for more details.
 ***********************************************************************/
 
-/********************************************************************** 
+/**********************************************************************
   An IO layer to support transparent compression/uncompression.
   (Currently only "required" functionality is supported.)
 
   There are various reasons for making this a full-blown module
   instead of just defining a few macros:
-  
+
   - Ability to switch between compressed and uncompressed at run-time
     (zlib with compression level 0 saves uncompressed, but still with
     gzip header, so non-zlib server cannot read the savefile).
-    
+
   - Flexibility to add other methods if desired (eg, bzip2, arbitrary
     external filter program, etc).
 
@@ -38,6 +38,15 @@
 #include <stdio.h>
 #include <string.h>
 
+/* Must be before <windows.h> gets included from anywhere */
+#ifdef HAVE_WINSOCK
+#ifdef HAVE_WINSOCK2
+#include <winsock2.h>
+#else  /* HAVE_WINSOCK2 */
+#include <winsock.h>
+#endif /* HAVE_WINSOCK2 */
+#endif /* HAVE_WINSOCK */
+
 #ifdef HAVE_LIBZ
 #include <zlib.h>
 #endif
@@ -198,6 +207,9 @@ fz_FILE *fz_from_file(const char *filename, const char *in_mode,
     if (fp->u.bz2.plain) {
       fp->u.bz2.file = BZ2_bzReadOpen(&fp->u.bz2.error, fp->u.bz2.plain, 1, 0,
                                       NULL, 0);
+    } else {
+      /* This may currently have garbage value assigned via other union member. */
+      fp->u.bz2.file = NULL;
     }
     if (!fp->u.bz2.file) {
       if (fp->u.bz2.plain) {
@@ -487,7 +499,7 @@ char *fz_fgets(char *buffer, int size, fz_FILE *fp)
       int i, j;
 
       for (i = 0; i < size - 1; i += j) {
-        ssize_t len = 0;
+        size_t len = 0;
         bool line_end;
 
         for (j = 0, line_end = FALSE; fp->u.xz.out_avail > 0
@@ -507,7 +519,7 @@ char *fz_fgets(char *buffer, int size, fz_FILE *fp)
         }
 
         if (fp->u.xz.hack_byte_used) {
-          ssize_t hblen = 0;
+          size_t hblen = 0;
 
           fp->u.xz.in_buf[0] = fp->u.xz.hack_byte;
           len = fread(fp->u.xz.in_buf + 1, 1, PLAIN_FILE_BUF_SIZE - 1,
@@ -517,11 +529,11 @@ char *fz_fgets(char *buffer, int size, fz_FILE *fp)
           if (len <= 1) {
             hblen = fread(&fp->u.xz.hack_byte, 1, 1, fp->u.xz.plain);
           }
-          if (hblen <= 0) {
+          if (hblen == 0) {
             fp->u.xz.hack_byte_used = FALSE;
           }
         }
-        if (len <= 0) {
+        if (len == 0) {
           if (fp->u.xz.error == LZMA_STREAM_END) {
             if (i + j == 0) {
               /* Plain file read complete, and there was nothing in xz buffers
@@ -634,8 +646,8 @@ char *fz_fgets(char *buffer, int size, fz_FILE *fp)
 static bool xz_outbuffer_to_file(fz_FILE *fp, lzma_action action)
 {
   do {
-    ssize_t len;
-    ssize_t total = 0;
+    size_t len;
+    size_t total = 0;
 
     fp->u.xz.error = lzma_code(&fp->u.xz.stream, action);
 
@@ -648,7 +660,7 @@ static bool xz_outbuffer_to_file(fz_FILE *fp, lzma_action action)
                    PLAIN_FILE_BUF_SIZE - fp->u.xz.stream.avail_out - total,
                    fp->u.xz.plain);
       total += len;
-      if (len <= 0) {
+      if (len == 0) {
         return FALSE;
       }
     }
