@@ -44,8 +44,12 @@
 #include <sys/signal.h>
 #endif
 #ifdef HAVE_WINSOCK
+#ifdef HAVE_WINSOCK2
+#include <winsock2.h>
+#else  /* HAVE_WINSOCK2 */
 #include <winsock.h>
-#endif
+#endif /* HAVE_WINSOCK2 */
+#endif /* HAVE_WINSOCK */
 #ifdef WIN32_NATIVE
 #include <windows.h>	/* GetTempPath */
 #endif
