@@ -39,6 +39,10 @@ extern "C" {
    another unreachable condition. */
 #define FC_INFINITY    	(1000 * 1000 * 1000)
 
+/* Initialize something for the sole purpose of silencing false compiler warning
+ * about variable possibly used uninitialized. */
+#define BAD_HEURISTIC_INIT(_ini_val_) = _ini_val_
+
 enum fc_tristate { TRI_NO, TRI_YES, TRI_MAYBE };
 #define BOOL_TO_TRISTATE(tri) ((tri) ? TRI_YES : TRI_NO)
 
